@@ -7,19 +7,19 @@
 #' 'integer', 'decimal', and 'text'.
 #'
 #' @details
-#' The valueType is a property of a variable and is required in certain 
-#' functions to determine the handling of the variables. The valueType refers 
-#' to the OBiBa-internal type of a variable. It is specified in a data 
-#' dictionary in a column `valueType` and can be associated with variables as 
-#' attributes. Acceptable valueTypes include 'text', 'integer', 'decimal', 
-#' 'boolean', datetime', 'date'). The full list of OBiBa valueType 
-#' possibilities and their correspondence with R data types are available using 
-#' [madshapR::valueType_list].
+#' The valueType is a declared property of a variable that is required in 
+#' certain functions to determine handling of the variables. Specifically, 
+#' valueType refers to the 
+#' [OBiBa data type of a variable](https://opaldoc.obiba.org/en/dev/variables-data.html#value-types). 
+#' The valueType is specified in a data dictionary in a column 'valueType' and 
+#' can be associated with variables as attributes. Acceptable valueTypes 
+#' include 'text', 'integer', 'decimal', 'boolean', datetime', 'date'. The full 
+#' list of OBiBa valueType possibilities and their correspondence with R data 
+#' types are available using [valueType_list]. The valueType can be used to 
+#' coerce the variable to the corresponding data type.
 #' 
 #' @seealso
 #' [typeof()], [class()]
-#' [madshapR::valueType_list] for insights about possible valueType and
-#' translation into type and class in R.
 #' [Opal documentation](https://opaldoc.obiba.org/en/dev/magma-user-guide/value/type.html)
 #'
 #' @param x Object. Can be a vector.
@@ -30,9 +30,9 @@
 #' @examples
 #' {
 #' 
-#' # use DEMO_files provided by the package
+#' # use madshapR_DEMO provided by the package
 #'
-#' dataset <- DEMO_files$dataset_MELBOURNE_1
+#' dataset <- madshapR_DEMO$dataset_MELBOURNE
 #' valueType_of(dataset$Gender)
 #' valueType_of(iris$Sepal.Length)
 #'
@@ -62,8 +62,8 @@ valueType_of <- function(x){
       which(vT_list[['typeof']] == type &
             vT_list[['class']]  == class),]$`toValueType`)
 
-  if(type == "double" & class == "Date")    valueType <- "date"
-  if(type == "double" & class == "POSIXt")  valueType <- "datetime"
+  if(type %in% c("character","double") & class == "Date")    valueType <- "date"
+  if(type %in% c("character","double") & class == "POSIXt")  valueType <- "datetime"
 
   silently_run({
     if(class == "factor"){
@@ -99,32 +99,34 @@ valueType_of <- function(x){
 #' 'text'.
 #'
 #' @details
-#' A data dictionary contains metadata about variables and can be associated 
-#' with a dataset. It must be a list of data frame-like objects with elements 
-#' named 'Variables' (required) and 'Categories' (if any). To be usable in any 
-#' function, the 'Variables' element must contain at least the 'name' column, 
-#' and the 'Categories' element must contain at least the 'variable' and 'name' 
-#' columns. To be considered as a minimum workable data dictionary, in 
-#' 'Variables' the 'name' column must also have unique and non-null entries, 
-#' and in 'Categories' the combination of 'variable' and 'name' columns must 
-#' also be unique'.
+#' A data dictionary contains the list of variables in a dataset and metadata 
+#' about the variables and can be associated with a dataset. A data dictionary 
+#' object is a list of data frame(s) named 'Variables' (required) and 
+#' 'Categories' (if any). To be usable in any function, the data frame 
+#' 'Variables' must contain at least the `name` column, with all unique and 
+#' non-missing entries, and the data frame 'Categories' must contain at least 
+#' the `variable` and `name` columns, with unique combination of 
+#' `variable` and `name`.
 #'
-#' A dataset must be a data frame-like object and can be associated with a 
-#' data dictionary. If no data dictionary is provided, a minimum workable 
-#' data dictionary will be generated as needed by relevant functions. 
-#' An identifier `id` column for sorting can be specified by the user. If 
-#' specified, the `id` values must be non-missing and will be used in functions 
-#' that require it. If no identifier column is specified, indexing is handled 
-#' automatically by the function.
+#' A dataset is a data table containing variables. A dataset object is a 
+#' data frame and can be associated with a data dictionary. If no 
+#' data dictionary is provided with a dataset, a minimum workable 
+#' data dictionary will be generated as needed within relevant functions.
+#' Identifier variable(s) for indexing can be specified by the user. 
+#' The id values must be non-missing and will be used in functions that 
+#' require it. If no identifier variable is specified, indexing is 
+#' handled automatically by the function.
 #' 
-#' The valueType is a property of a variable and is required in certain 
-#' functions to determine the handling of the variables. The valueType refers 
-#' to the OBiBa-internal type of a variable. It is specified in a data 
-#' dictionary in a column `valueType` and can be associated with variables as 
-#' attributes. Acceptable valueTypes include 'text', 'integer', 'decimal', 
-#' 'boolean', datetime', 'date'). The full list of OBiBa valueType 
-#' possibilities and their correspondence with R data types are available using 
-#' [madshapR::valueType_list].
+#' The valueType is a declared property of a variable that is required in 
+#' certain functions to determine handling of the variables. Specifically, 
+#' valueType refers to the 
+#' [OBiBa data type of a variable](https://opaldoc.obiba.org/en/dev/variables-data.html#value-types). 
+#' The valueType is specified in a data dictionary in a column 'valueType' and 
+#' can be associated with variables as attributes. Acceptable valueTypes 
+#' include 'text', 'integer', 'decimal', 'boolean', datetime', 'date'. The full 
+#' list of OBiBa valueType possibilities and their correspondence with R data 
+#' types are available using [valueType_list]. The valueType can be used to 
+#' coerce the variable to the corresponding data type.
 #'
 #' @seealso
 #' [valueType_adjust()]
@@ -132,7 +134,7 @@ valueType_of <- function(x){
 #' @param ... Object that can be either a dataset or a data dictionary.
 #'
 #' @returns
-#' Either a tibble, identifying the dataset, or a list of tibble(s)
+#' Either a data frame, identifying the dataset, or a list of data frame(s)
 #' identifying a data dictionary, depending which the input refers to.
 #'
 #' @examples
@@ -142,11 +144,11 @@ valueType_of <- function(x){
 #' # evaluated as whole, and the best valueType match found is applied. If 
 #' # there is no better match found, the column is left as it is.
 #' 
-#' valueType_self_adjust(mtcars['cyl'])
+#' head(valueType_self_adjust(mtcars['cyl']))
 #'
 #' }
 #'
-#' @import dplyr tidyr stringr
+#' @import dplyr tidyr stringr fabR
 #' @importFrom rlang .data
 #'
 #' @export
@@ -156,11 +158,12 @@ valueType_self_adjust <- function(...){
 
   if(is_dataset(...) & !is_data_dict(...)){
     
-    dataset <- as_dataset(...,col_id = attributes(...)$`madshapR::col_id`)
+    dataset <- as_dataset(...,col_id = col_id(...))
     
     if(ncol(dataset) == 0) return(dataset)
+    if(nrow(dataset) == 0) return(dataset)
     
-    preserve_attributes <- attributes(dataset)$`madshapR::col_id`
+    preserve_attributes <- col_id(dataset)
 
     is_factor <-
       dataset %>%
@@ -293,7 +296,13 @@ The valueType will remain as it is.")
     return(data_dict)
   }
 
-  stop(call. = FALSE, "The argument is neither a dataset or a data dictionary.")
+  message("The argument is neither a dataset or a data dictionary.")
+  message("\nTesting dataset :")
+  try(as_dataset(...))
+  
+  message("\nTesting data dictionary :")
+  try(as_data_dict(...))
+  silently_run(stop(call. = FALSE))
 }
 
 #' @title
@@ -309,32 +318,34 @@ The valueType will remain as it is.")
 #' 'decimal', and text'.
 #'
 #' @details
-#' A data dictionary contains metadata about variables and can be associated 
-#' with a dataset. It must be a list of data frame-like objects with elements 
-#' named 'Variables' (required) and 'Categories' (if any). To be usable in any 
-#' function, the 'Variables' element must contain at least the 'name' column, 
-#' and the 'Categories' element must contain at least the 'variable' and 'name' 
-#' columns. To be considered as a minimum workable data dictionary, in 
-#' 'Variables' the 'name' column must also have unique and non-null entries, 
-#' and in 'Categories' the combination of 'variable' and 'name' columns must 
-#' also be unique'.
+#' A data dictionary contains the list of variables in a dataset and metadata 
+#' about the variables and can be associated with a dataset. A data dictionary 
+#' object is a list of data frame(s) named 'Variables' (required) and 
+#' 'Categories' (if any). To be usable in any function, the data frame 
+#' 'Variables' must contain at least the `name` column, with all unique and 
+#' non-missing entries, and the data frame 'Categories' must contain at least 
+#' the `variable` and `name` columns, with unique combination of 
+#' `variable` and `name`.
 #'
-#' A dataset must be a data frame-like object and can be associated with a 
-#' data dictionary. If no data dictionary is provided, a minimum workable 
-#' data dictionary will be generated as needed by relevant functions. 
-#' An identifier `id` column for sorting can be specified by the user. If 
-#' specified, the `id` values must be non-missing and will be used in functions 
-#' that require it. If no identifier column is specified, indexing is handled 
-#' automatically by the function.
+#' A dataset is a data table containing variables. A dataset object is a 
+#' data frame and can be associated with a data dictionary. If no 
+#' data dictionary is provided with a dataset, a minimum workable 
+#' data dictionary will be generated as needed within relevant functions.
+#' Identifier variable(s) for indexing can be specified by the user. 
+#' The id values must be non-missing and will be used in functions that 
+#' require it. If no identifier variable is specified, indexing is 
+#' handled automatically by the function.
 #' 
-#' The valueType is a property of a variable and is required in certain 
-#' functions to determine the handling of the variables. The valueType refers 
-#' to the OBiBa-internal type of a variable. It is specified in a data 
-#' dictionary in a column `valueType` and can be associated with variables as 
-#' attributes. Acceptable valueTypes include 'text', 'integer', 'decimal', 
-#' 'boolean', datetime', 'date'). The full list of OBiBa valueType 
-#' possibilities and their correspondence with R data types are available using 
-#' [madshapR::valueType_list].
+#' The valueType is a declared property of a variable that is required in 
+#' certain functions to determine handling of the variables. Specifically, 
+#' valueType refers to the 
+#' [OBiBa data type of a variable](https://opaldoc.obiba.org/en/dev/variables-data.html#value-types). 
+#' The valueType is specified in a data dictionary in a column 'valueType' and 
+#' can be associated with variables as attributes. Acceptable valueTypes 
+#' include 'text', 'integer', 'decimal', 'boolean', datetime', 'date'. The full 
+#' list of OBiBa valueType possibilities and their correspondence with R data 
+#' types are available using [valueType_list]. The valueType can be used to 
+#' coerce the variable to the corresponding data type.
 #'
 #' @seealso
 #' [valueType_self_adjust()]
@@ -345,21 +356,22 @@ The valueType will remain as it is.")
 #' dictionary. NULL by default.
 #'
 #' @returns
-#' Either a tibble, identifying the dataset, or a list of tibble(s)
+#' Either a data frame, identifying the dataset, or a list of data frame(s)
 #' identifying a data dictionary, depending which is 'to'.
 #'
 #' @examples
 #' {
 #' 
-#' # use DEMO_files provided by the package
+#' # use madshapR_DEMO provided by the package
 #' library(dplyr)
 #' 
-#' dataset <- DEMO_files$dataset_TOKYO[c(1:4),'prg_ever']
+#' dataset <- madshapR_DEMO$dataset_TOKYO[c(1:4),'prg_ever']
 #' data_dict <-
-#'   DEMO_files$dd_TOKYO_format_maelstrom %>%
+#'   madshapR_DEMO$data_dict_TOKYO %>%
 #'   data_dict_filter(filter_var = 'name == "prg_ever"') %>%
 #'   as_data_dict_mlstr()
-#' valueType_adjust(from = dataset,to = data_dict)
+#' 
+#' head(valueType_adjust(from = data_dict,to = dataset))
 #' 
 #' }
 #'
@@ -476,8 +488,33 @@ bold("\n\nUseful tip:"),
     return(dataset)
   }
 
-  stop(call. = FALSE,
-       "The arguments are neither or (both) a dataset or a data dictionary.")
+  if(is_dataset(from) & is_dataset(to))
+    stop(call. = FALSE, "The argument are both datasets.")
+  
+  if(is_data_dict(from) & is_data_dict(to))
+    stop(call. = FALSE, "The argument are both data dictionaries.")
+  
+  if(is_dataset(to))   { 
+    message("The argument is not a data dictionary.")
+    as_data_dict(from) }
+  
+  if(is_dataset(from)) { 
+    message("The argument is not a data dictionary.")
+    as_data_dict(to) }
+  
+  if(is_data_dict(to))   { 
+    message("The argument is not a dataset.")
+    as_data_dict(from) }
+  
+  if(is_data_dict(from)) { 
+    message("The argument is not a dataset.")
+    as_dataset(to) }
+  
+  message(
+"The arguments are neither a dataset nor a data dictionary.")
+  
+  silently_run(stop(call. = FALSE))
+  
 }
 
 #' @title
@@ -489,32 +526,34 @@ bold("\n\nUseful tip:"),
 #' 'decimal', then 'date'. If all others fail, the default valueType is 'text'.
 #'
 #' @details
-#' A data dictionary contains metadata about variables and can be associated 
-#' with a dataset. It must be a list of data frame-like objects with elements 
-#' named 'Variables' (required) and 'Categories' (if any). To be usable in any 
-#' function, the 'Variables' element must contain at least the 'name' column, 
-#' and the 'Categories' element must contain at least the 'variable' and 'name' 
-#' columns. To be considered as a minimum workable data dictionary, in 
-#' 'Variables' the 'name' column must also have unique and non-null entries, 
-#' and in 'Categories' the combination of 'variable' and 'name' columns must 
-#' also be unique'.
+#' A data dictionary contains the list of variables in a dataset and metadata 
+#' about the variables and can be associated with a dataset. A data dictionary 
+#' object is a list of data frame(s) named 'Variables' (required) and 
+#' 'Categories' (if any). To be usable in any function, the data frame 
+#' 'Variables' must contain at least the `name` column, with all unique and 
+#' non-missing entries, and the data frame 'Categories' must contain at least 
+#' the `variable` and `name` columns, with unique combination of 
+#' `variable` and `name`.
 #'
-#' A dataset must be a data frame-like object and can be associated with a 
-#' data dictionary. If no data dictionary is provided, a minimum workable 
-#' data dictionary will be generated as needed by relevant functions. 
-#' An identifier `id` column for sorting can be specified by the user. If 
-#' specified, the `id` values must be non-missing and will be used in functions 
-#' that require it. If no identifier column is specified, indexing is handled 
-#' automatically by the function.
+#' A dataset is a data table containing variables. A dataset object is a 
+#' data frame and can be associated with a data dictionary. If no 
+#' data dictionary is provided with a dataset, a minimum workable 
+#' data dictionary will be generated as needed within relevant functions.
+#' Identifier variable(s) for indexing can be specified by the user. 
+#' The id values must be non-missing and will be used in functions that 
+#' require it. If no identifier variable is specified, indexing is 
+#' handled automatically by the function.
 #' 
-#' The valueType is a property of a variable and is required in certain 
-#' functions to determine the handling of the variables. The valueType refers 
-#' to the OBiBa-internal type of a variable. It is specified in a data 
-#' dictionary in a column `valueType` and can be associated with variables as 
-#' attributes. Acceptable valueTypes include 'text', 'integer', 'decimal', 
-#' 'boolean', datetime', 'date'). The full list of OBiBa valueType 
-#' possibilities and their correspondence with R data types are available using 
-#' [madshapR::valueType_list].
+#' The valueType is a declared property of a variable that is required in 
+#' certain functions to determine handling of the variables. Specifically, 
+#' valueType refers to the 
+#' [OBiBa data type of a variable](https://opaldoc.obiba.org/en/dev/variables-data.html#value-types). 
+#' The valueType is specified in a data dictionary in a column 'valueType' and 
+#' can be associated with variables as attributes. Acceptable valueTypes 
+#' include 'text', 'integer', 'decimal', 'boolean', datetime', 'date'. The full 
+#' list of OBiBa valueType possibilities and their correspondence with R data 
+#' types are available using [valueType_list]. The valueType can be used to 
+#' coerce the variable to the corresponding data type.
 #'
 #' @seealso
 #' [Opal documentation](https://opaldoc.obiba.org/en/dev/magma-user-guide/value/type.html)
@@ -527,13 +566,11 @@ bold("\n\nUseful tip:"),
 #' @examples
 #' {
 #' 
-#' # use DEMO_files provided by the package
+#' # use madshapR_DEMO provided by the package
 #'
-#' dataset <- DEMO_files$dataset_TOKYO
-#' valueType_of(dataset$dob)
+#' dataset <- madshapR_DEMO$dataset_TOKYO
 #' valueType_guess(dataset$dob)
 #' 
-#' valueType_of(mtcars$cyl)
 #' valueType_guess(mtcars$cyl)
 #' 
 #'}
@@ -544,17 +581,20 @@ bold("\n\nUseful tip:"),
 #' @export
 valueType_guess <- function(x){
 
-  # test
-  x <- unique(x)
-
   # check if the col is empty
   if(is.list(x) & sum(nrow(x)) <= 1)
-    return(as_valueType(x = x[[1]]))
-
+    return(valueType_guess(x = x[[1]]))
+  
   # check if the col is a vector
   if(is.list(x))
     stop(call. = FALSE,"'list' object cannot be coerced to valueType")
+  
+  # check if all is na
+  if(all(is.na(x))) return(valueType_of(x))
 
+  # else :
+  x <-   unique(x)
+  
   vT_list <- madshapR::valueType_list
 
   test_vT_boolean  <- 
@@ -610,21 +650,23 @@ valueType_guess <- function(x){
 }
 
 #' @title
-#' Validate and coerce an object according to a given valueType
+#' Validate and coerce any object according to a given valueType
 #'
 #' @description
-#' Attributes a valueType to an object, that can be a vector, or in a tibble 
+#' Attributes a valueType to an object, that can be a vector, or in a data frame 
 #' using [dplyr::mutate].
 #'
 #' @details
-#' The valueType is a property of a variable and is required in certain 
-#' functions to determine the handling of the variables. The valueType refers 
-#' to the OBiBa-internal type of a variable. It is specified in a data 
-#' dictionary in a column `valueType` and can be associated with variables as 
-#' attributes. Acceptable valueTypes include 'text', 'integer', 'decimal', 
-#' 'boolean', datetime', 'date'). The full list of OBiBa valueType 
-#' possibilities and their correspondence with R data types are available using 
-#' [madshapR::valueType_list].
+#' The valueType is a declared property of a variable that is required in 
+#' certain functions to determine handling of the variables. Specifically, 
+#' valueType refers to the 
+#' [OBiBa data type of a variable](https://opaldoc.obiba.org/en/dev/variables-data.html#value-types). 
+#' The valueType is specified in a data dictionary in a column 'valueType' and 
+#' can be associated with variables as attributes. Acceptable valueTypes 
+#' include 'text', 'integer', 'decimal', 'boolean', datetime', 'date'. The full 
+#' list of OBiBa valueType possibilities and their correspondence with R data 
+#' types are available using [valueType_list]. The valueType can be used to 
+#' coerce the variable to the corresponding data type.
 #'
 #' @seealso
 #' [Opal documentation](https://opaldoc.obiba.org/en/dev/magma-user-guide/value/type.html)
@@ -638,16 +680,14 @@ valueType_guess <- function(x){
 #' @examples
 #' {
 #' 
-#' # use DEMO_files provided by the package
+#' # use madshapR_DEMO provided by the package
 #'
-#' dataset <- DEMO_files$dataset_TOKYO
-#' valueType_of(dataset$dob)
-#' valueType_guess(dataset$dob)
-#' as_valueType(dataset$dob,'date') 
+#' dataset <- madshapR_DEMO$dataset_TOKYO
+#' as_valueType(head(dataset$dob),'date')
 #' 
 #' # as_valueType is compatible with tidyverse philosophy
 #' library(dplyr)
-#' mtcars %>% mutate(cyl = as_valueType(cyl,'integer'))
+#' mtcars %>% mutate(cyl = as_valueType(cyl,'integer')) %>% head()
 #' 
 #'}
 #'
@@ -776,25 +816,22 @@ For further investigation, you can use dataset_evaluate(dataset, data_dict).")
 }
 
 #' @title
-#' Validate and coerce an object to taxonomy format
+#' Validate and coerce any object as a taxonomy
 #'
 #' @description
 #' Confirms that the input object is a valid taxonomy and returns it as a
-#' taxonomy with the appropriate 'madshapR::class' attribute. This function 
+#' taxonomy with the appropriate `madshapR::class` attribute. This function 
 #' mainly helps validate input within other functions of the package but could 
 #' be used to check if a taxonomy is valid.
 #'
 #' @details
-#' A taxonomy is classification scheme that can be defined for variable 
-#' attributes. If defined, a taxonomy must be a data frame-like object. It must 
-#' be compatible with (and is generally extracted from) an Opal environment. To 
-#' work with certain functions, a valid taxonomy must contain at least the 
-#' columns 'taxonomy', 'vocabulary', and 'terms'. In addition, the taxonomy
-#' may follow Maelstrom research taxonomy, and its content can be evaluated
-#' accordingly, such as naming convention restriction, tagging elements,
-#' or scales, which are specific to Maelstrom Research. In this particular
-#' case, the tibble must also contain 'vocabulary_short', 'taxonomy_scale',
-#' 'vocabulary_scale' and 'term_scale' to work with some specific functions.
+#' A taxonomy is a classification schema that can be defined for variable 
+#' attributes. A taxonomy is usually extracted from an 
+#' [Opal environment](https://www.obiba.org/pages/products/opal/), and a 
+#' taxonomy object is a data frame that must contain at least the columns 
+#' `taxonomy`, `vocabulary`, and `terms`. Additional details about Opal 
+#' taxonomies are 
+#' [available online](https://opaldoc.obiba.org/en/latest/web-user-guide/administration/taxonomies.html).
 #' 
 #' @seealso
 #' [Opal documentation](https://opaldoc.obiba.org/en/dev/magma-user-guide/value/type.html)
@@ -802,15 +839,15 @@ For further investigation, you can use dataset_evaluate(dataset, data_dict).")
 #' @param object A potential taxonomy to be coerced.
 #'
 #' @returns
-#' A tibble identifying a taxonomy (generally generated from Opal taxonomy).
+#' A list of data frame(s) with `madshapR::class` 'taxonomy'.
 #'
 #' @examples
 #' {
 #' 
-#' # use DEMO_files provided by the package
+#' # use madshapR_DEMO provided by the package
 #'
 #' ###### Example
-#' as_taxonomy(DEMO_files$taxonomy_PARIS)
+#' as_taxonomy(madshapR_DEMO$taxonomy_PARIS)
 #' 
 #'}
 #'
@@ -825,8 +862,7 @@ as_taxonomy <- function(object){
     stop(call. = FALSE,
 "\n
 This object is not a taxonomy as defined by Maelstrom standards, which must 
-be a data frame (or tibble) containing at least 'taxonomy', 'vocabulary' and 
-'term' columns. 
+be a data frame containing at least 'taxonomy', 'vocabulary' and 'term' columns. 
 Please refer to documentation.",
 
 #       bold("\n\nUseful tip:"),
@@ -838,7 +874,9 @@ Please refer to documentation.",
   if(sum(names(object) %in%
      c("vocabulary_short","taxonomy_scale",
        "vocabulary_scale","term_scale")) == 4){
-
+    
+    ## create index if not exists
+    
     attributes(object)$`madshapR::class` <- "taxonomy_mlstr"
   }else{
     attributes(object)$`madshapR::class` <- "taxonomy_opal"}
@@ -857,14 +895,16 @@ Please refer to documentation.",
 #' to check if a valueType is valid.
 #'
 #' @details
-#' The valueType is a property of a variable and is required in certain 
-#' functions to determine the handling of the variables. The valueType refers 
-#' to the OBiBa-internal type of a variable. It is specified in a data 
-#' dictionary in a column `valueType` and can be associated with variables as 
-#' attributes. Acceptable valueTypes include 'text', 'integer', 'decimal', 
-#' 'boolean', datetime', 'date'). The full list of OBiBa valueType 
-#' possibilities and their correspondence with R data types are available using 
-#' [madshapR::valueType_list].
+#' The valueType is a declared property of a variable that is required in 
+#' certain functions to determine handling of the variables. Specifically, 
+#' valueType refers to the 
+#' [OBiBa data type of a variable](https://opaldoc.obiba.org/en/dev/variables-data.html#value-types). 
+#' The valueType is specified in a data dictionary in a column 'valueType' and 
+#' can be associated with variables as attributes. Acceptable valueTypes 
+#' include 'text', 'integer', 'decimal', 'boolean', datetime', 'date'. The full 
+#' list of OBiBa valueType possibilities and their correspondence with R data 
+#' types are available using [valueType_list]. The valueType can be used to 
+#' coerce the variable to the corresponding data type.
 #'
 #' @seealso
 #' [Opal documentation](https://opaldoc.obiba.org/en/dev/magma-user-guide/value/type.html)
@@ -907,16 +947,13 @@ is_valueType <- function(object){
 #' used to check if a taxonomy is valid.
 #'
 #' @details
-#' A taxonomy is classification scheme that can be defined for variable 
-#' attributes. If defined, a taxonomy must be a data frame-like object. It must 
-#' be compatible with (and is generally extracted from) an Opal environment. To 
-#' work with certain functions, a valid taxonomy must contain at least the 
-#' columns 'taxonomy', 'vocabulary', and 'terms'. In addition, the taxonomy
-#' may follow Maelstrom research taxonomy, and its content can be evaluated
-#' accordingly, such as naming convention restriction, tagging elements,
-#' or scales, which are specific to Maelstrom Research. In this particular
-#' case, the tibble must also contain 'vocabulary_short', 'taxonomy_scale',
-#' 'vocabulary_scale' and 'term_scale' to work with some specific functions.
+#' A taxonomy is a classification schema that can be defined for variable 
+#' attributes. A taxonomy is usually extracted from an 
+#' [Opal environment](https://www.obiba.org/pages/products/opal/), and a 
+#' taxonomy object is a data frame that must contain at least the columns 
+#' `taxonomy`, `vocabulary`, and `terms`. Additional details about Opal 
+#' taxonomies are 
+#' [available online](https://opaldoc.obiba.org/en/latest/web-user-guide/administration/taxonomies.html).
 #'
 #' @param object A potential taxonomy to be evaluated.
 #'
@@ -926,11 +963,9 @@ is_valueType <- function(object){
 #' @examples
 #' {
 #' 
-#' # use DEMO_files provided by the package
+#' # use madshapR_DEMO provided by the package
 #'
-#' is_taxonomy(DEMO_files$taxonomy_PARIS)
-#' is_taxonomy(DEMO_files$taxonomy_opal_mlstr)
-#' is_taxonomy(iris)
+#' is_taxonomy(madshapR_DEMO$taxonomy_PARIS)
 #'
 #'}
 #'
@@ -941,7 +976,7 @@ is_valueType <- function(object){
 is_taxonomy <- function(object){
 
   object <- object
-  # if only the tibble is given in parameter
+  # if only the data frame is given in parameter
   test <- silently_run(try(as_taxonomy(object),silent = TRUE))
   if(class(test)[1] == 'try-error')    return(FALSE)
   return(TRUE)
